OGG
===


Ogg bitstreams and pages
------------------------

.. automodule:: mutagen.ogg

.. autoexception:: mutagen.ogg.error

.. autoclass:: mutagen.ogg.OggFileType(filename)
    :show-inheritance:

.. autoclass:: mutagen.ogg.OggPage
    :members:


Ogg Vorbis
----------

.. automodule:: mutagen.oggvorbis

.. autoexception:: mutagen.oggvorbis.error
    :show-inheritance:

.. autoexception:: mutagen.oggvorbis.OggVorbisHeaderError
    :show-inheritance:

.. autoclass:: mutagen.oggvorbis.OggVorbis(filename)
    :show-inheritance:

.. autoclass:: mutagen.oggvorbis.OggVorbisInfo
    :members:

Ogg Opus
--------

.. automodule:: mutagen.oggopus

.. autoexception:: mutagen.oggopus.error
    :show-inheritance:

.. autoexception:: mutagen.oggopus.OggOpusHeaderError
    :show-inheritance:

.. autoclass:: mutagen.oggopus.OggOpus(filename)
    :show-inheritance:

.. autoclass:: mutagen.oggopus.OggOpusInfo
    :members:


Ogg Speex
---------

.. automodule:: mutagen.oggspeex

.. autoexception:: mutagen.oggspeex.error
    :show-inheritance:

.. autoexception:: mutagen.oggspeex.OggSpeexHeaderError
    :show-inheritance:

.. autoclass:: mutagen.oggspeex.OggSpeex(filename)
    :show-inheritance:

.. autoclass:: mutagen.oggspeex.OggSpeexInfo
    :members:


Ogg Theora
----------

.. automodule:: mutagen.oggtheora

.. autoexception:: mutagen.oggtheora.error
    :show-inheritance:

.. autoexception:: mutagen.oggtheora.OggTheoraHeaderError
    :show-inheritance:

.. autoclass:: mutagen.oggtheora.OggTheora(filename)
    :show-inheritance:

.. autoclass:: mutagen.oggtheora.OggTheoraInfo
    :members:


Ogg FLAC
--------

.. automodule:: mutagen.oggflac

.. autoexception:: mutagen.oggflac.error
    :show-inheritance:

.. autoexception:: mutagen.oggflac.OggFLACHeaderError
    :show-inheritance:

.. autoclass:: mutagen.oggflac.OggFLAC(filename)
    :show-inheritance:

.. autoclass:: mutagen.oggflac.OggFLACStreamInfo
    :members:

